import requests
from .base import Base

class Template(Base):
    def __init__(self, url: str):
        super().__init__(f"{url}/template")

    def view(self, params: dict = None) -> list:
        response = requests.get(self.convert(params), headers=self.headers)
        payload = response.json()
        if not response.ok:
            raise Exception(payload)
        return payload

    def create(self, params: dict) -> dict:
        response = requests.post(self.url, json=params, headers=self.headers)
        payload = response.json()
        if not response.ok:
            raise Exception(payload)
        return payload

    def update(self, params: dict) -> str:
        response = requests.put(self.url, json=params, headers=self.headers)
        payload = response.text
        if not response.ok:
            raise Exception(payload)
        return payload

    def delete(self, params: dict) -> str:
        response = requests.delete(self.convert(params), headers=self.headers)
        payload = response.text
        if not response.ok:
            raise Exception(payload)
        return payload

    def find_one(self, params: dict) -> dict:
        response = requests.get(self.convert(params), headers=self.headers)
        payload = response.json()
        if not response.ok:
            raise Exception(payload)
        return payload


import urllib

class Base:
    def __init__(self, url: str):
        self.url = url
        self.headers = {
            "Content-Type": "application/json"
        }

    def set_token(self, token: str):
        self.headers['Authorization'] = token

    def convert(self, params: dict = None) -> str:
        
        if params is None:
            return self.url

        raw_params = urllib.parse.urlencode(params)

        return f"{self.url}?{raw_params}"


from .base import Base
from .auth import Auth
from .meli import Meli
from .template import Template

__all__ = [
    'BaseClass1',
    'BaseClass2',
    'AuthClass',
    'MeliClass',
    'TemplateClass',
]


import requests
from .base import Base

class Auth(Base):
    def __init__(self, url: str):
        super().__init__(url)

    def sign_up(self, params: dict) -> str:
        response = requests.post(f'{self.url}/sign-up', json=params, headers=self.headers)
        payload = response.text
        if not response.ok:
            raise Exception(payload)
        self.set_token(payload)
        return payload

    def sign_in(self, params: dict) -> str:
        response = requests.post(f'{self.url}/sign-in', json=params, headers=self.headers)
        payload = response.text
        if not response.ok:
            raise Exception(payload)
        self.set_token(payload)
        return payload

    def verify_phone(self, params: dict) -> str:
        response = requests.post(f'{self.url}/verify-phone', json=params, headers=self.headers)
        payload = response.text
        if not response.ok:
            raise Exception(payload)
        return payload

    def verify_email(self, params: dict) -> str:
        response = requests.post(f'{self.url}/verify-email', json=params, headers=self.headers)
        payload = response.text
        if not response.ok:
            raise Exception(payload)
        return payload

    def check_username(self, username: str) -> bool:
        response = requests.post(f'{self.url}/check-username', json={'username': username}, headers=self.headers)
        payload = response.text
        if not response.ok:
            raise Exception(payload)
        return bool(payload)

    def check_phone(self, phone: str) -> bool:
        response = requests.post(f'{self.url}/check-phone', json={'phone': phone}, headers=self.headers)
        payload = response.text
        if not response.ok:
            raise Exception(payload)
        return bool(payload)

    def check_mail(self, mail: str) -> bool:
        response = requests.post(f'{self.url}/check-mail', json={'mail': mail}, headers=self.headers)
        payload = response.text
        if not response.ok:
            raise Exception(payload)
        return bool(payload)

    def active_account(self, params: dict) -> str:
        response = requests.post(f'{self.url}/active-account', json=params, headers=self.headers)
        payload = response.text
        if not response.ok:
            raise Exception(payload)
        return payload


from setuptools import setup, find_packages

setup(
    name='siura',
    version='1.1.0',
    packages=find_packages(),
    install_requires=[
        
    ],
    entry_points={
        'console_scripts': [
           
        ],
    },
    author='WAMY S.A.S',
    author_email='dev@siura.com',
    description='SDK for SIURA',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/siura/sdk',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)